@@ -38,6 +38,7 @@ from .._impl import (
     scout_compute_api_BitShiftRightFunction as BitShiftRightFunction,
     scout_compute_api_BitTestFunction as BitTestFunction,
     scout_compute_api_BitXorFunction as BitXorFunction,
+    scout_compute_api_Bode as Bode,
     scout_compute_api_BucketedCartesian3dPlot as BucketedCartesian3dPlot,
     scout_compute_api_BucketedCartesianPlot as BucketedCartesianPlot,
     scout_compute_api_BucketedEnumArrayPlot as BucketedEnumArrayPlot,
@@ -82,6 +83,7 @@ from .._impl import (
     scout_compute_api_ComputeWithUnitsResult as ComputeWithUnitsResult,
     scout_compute_api_Context as Context,
     scout_compute_api_Count as Count,
+    scout_compute_api_Cpsd as Cpsd,
     scout_compute_api_CumulativeSumSeries as CumulativeSumSeries,
     scout_compute_api_CurveFit as CurveFit,
     scout_compute_api_CurveFitDetails as CurveFitDetails,
@@ -101,6 +103,7 @@ from .._impl import (
     scout_compute_api_DerivativeSeries as DerivativeSeries,
     scout_compute_api_DerivedSeries as DerivedSeries,
     scout_compute_api_DerivedSeriesVisitor as DerivedSeriesVisitor,
+    scout_compute_api_DetrendType as DetrendType,
     scout_compute_api_DoubleConstant as DoubleConstant,
     scout_compute_api_DoubleConstantVisitor as DoubleConstantVisitor,
     scout_compute_api_DriverSeries3d as DriverSeries3d,
@@ -145,6 +148,7 @@ from .._impl import (
     scout_compute_api_ExcludeNegativeValues as ExcludeNegativeValues,
     scout_compute_api_ExponentialCurve as ExponentialCurve,
     scout_compute_api_ExponentialResultDetails as ExponentialResultDetails,
+    scout_compute_api_ExtractStructFromStructSeries as ExtractStructFromStructSeries,
     scout_compute_api_Fft as Fft,
     scout_compute_api_FftWindow as FftWindow,
     scout_compute_api_FilterByExpressionSeries as FilterByExpressionSeries,
@@ -153,6 +157,12 @@ from .._impl import (
     scout_compute_api_ForwardFillResampleInterpolationConfiguration as ForwardFillResampleInterpolationConfiguration,
     scout_compute_api_FrequencyDomain as FrequencyDomain,
     scout_compute_api_FrequencyDomainPlot as FrequencyDomainPlot,
+    scout_compute_api_FrequencyDomainPlotComplex as FrequencyDomainPlotComplex,
+    scout_compute_api_FrequencyDomainPlotMagnitudeAndPhase as FrequencyDomainPlotMagnitudeAndPhase,
+    scout_compute_api_FrequencyDomainPlotV2 as FrequencyDomainPlotV2,
+    scout_compute_api_FrequencyDomainPlotV2Visitor as FrequencyDomainPlotV2Visitor,
+    scout_compute_api_FrequencyDomainV2 as FrequencyDomainV2,
+    scout_compute_api_FrequencyDomainV2Visitor as FrequencyDomainV2Visitor,
     scout_compute_api_FrequencyDomainVisitor as FrequencyDomainVisitor,
     scout_compute_api_FunctionDerivedSeries as FunctionDerivedSeries,
     scout_compute_api_FunctionParameterName as FunctionParameterName,
@@ -244,6 +254,7 @@ from .._impl import (
     scout_compute_api_NumericTimeShiftSeries as NumericTimeShiftSeries,
     scout_compute_api_NumericUnionOperation as NumericUnionOperation,
     scout_compute_api_NumericUnionSeries as NumericUnionSeries,
+    scout_compute_api_Nyquist as Nyquist,
     scout_compute_api_OffsetSeries as OffsetSeries,
     scout_compute_api_OnChangeRanges as OnChangeRanges,
     scout_compute_api_OutputFormat as OutputFormat,
@@ -274,6 +285,7 @@ from .._impl import (
     scout_compute_api_PowerResultDetails as PowerResultDetails,
     scout_compute_api_ProductSeries as ProductSeries,
     scout_compute_api_Property as Property,
+    scout_compute_api_Psd as Psd,
     scout_compute_api_Range as Range,
     scout_compute_api_RangeAggregation as RangeAggregation,
     scout_compute_api_RangeAggregationOperation as RangeAggregationOperation,
@@ -326,6 +338,7 @@ from .._impl import (
     scout_compute_api_StabilityWindowConfiguration as StabilityWindowConfiguration,
     scout_compute_api_StaleRanges as StaleRanges,
     scout_compute_api_StandardDeviation as StandardDeviation,
+    scout_compute_api_StftOptions as StftOptions,
     scout_compute_api_StringConstant as StringConstant,
     scout_compute_api_StringConstantVisitor as StringConstantVisitor,
     scout_compute_api_StringSetConstant as StringSetConstant,
@@ -381,6 +394,7 @@ from .._impl import (
     scout_compute_api_VariableValue as VariableValue,
     scout_compute_api_VariableValueVisitor as VariableValueVisitor,
     scout_compute_api_Window as Window,
+    scout_compute_api_WindowSymmetry as WindowSymmetry,
     scout_compute_api_WindowVisitor as WindowVisitor,
 )
 
@@ -423,6 +437,7 @@ __all__ = [
     'BitShiftRightFunction',
     'BitTestFunction',
     'BitXorFunction',
+    'Bode',
     'BucketedCartesian3dPlot',
     'BucketedCartesianPlot',
     'BucketedEnumArrayPlot',
@@ -466,6 +481,7 @@ __all__ = [
     'ComputeWithUnitsResult',
     'Context',
     'Count',
+    'Cpsd',
     'CumulativeSumSeries',
     'CurveFit',
     'CurveFitDetails',
@@ -485,6 +501,7 @@ __all__ = [
     'DerivativeSeries',
     'DerivedSeries',
     'DerivedSeriesVisitor',
+    'DetrendType',
     'DoubleConstant',
     'DoubleConstantVisitor',
     'DriverSeries3d',
@@ -529,6 +546,7 @@ __all__ = [
     'ExcludeNegativeValues',
     'ExponentialCurve',
     'ExponentialResultDetails',
+    'ExtractStructFromStructSeries',
     'Fft',
     'FftWindow',
     'FilterByExpressionSeries',
@@ -538,6 +556,12 @@ __all__ = [
     'FrequencyDomain',
     'FrequencyDomainVisitor',
     'FrequencyDomainPlot',
+    'FrequencyDomainPlotComplex',
+    'FrequencyDomainPlotMagnitudeAndPhase',
+    'FrequencyDomainPlotV2',
+    'FrequencyDomainPlotV2Visitor',
+    'FrequencyDomainV2',
+    'FrequencyDomainV2Visitor',
     'FunctionDerivedSeries',
     'FunctionParameterName',
     'FunctionParameterValue',
@@ -628,6 +652,7 @@ __all__ = [
     'NumericTimeShiftSeries',
     'NumericUnionOperation',
     'NumericUnionSeries',
+    'Nyquist',
     'OffsetSeries',
     'OnChangeRanges',
     'OutputFormat',
@@ -658,6 +683,7 @@ __all__ = [
     'PowerResultDetails',
     'ProductSeries',
     'Property',
+    'Psd',
     'Range',
     'RangeAggregation',
     'RangeAggregationOperation',
@@ -710,6 +736,7 @@ __all__ = [
     'StabilityWindowConfiguration',
     'StaleRanges',
     'StandardDeviation',
+    'StftOptions',
     'StringConstant',
     'StringConstantVisitor',
     'StringSetConstant',
@@ -766,6 +793,7 @@ __all__ = [
     'VariableValueVisitor',
     'Window',
     'WindowVisitor',
+    'WindowSymmetry',
     'ComputeService',
 ]
 
