@@ -11,6 +11,7 @@ from .._impl import (
     scout_compute_resolved_api_BandStopConfiguration as BandStopConfiguration,
     scout_compute_resolved_api_BinaryArithmeticSeriesNode as BinaryArithmeticSeriesNode,
     scout_compute_resolved_api_BitOperationSeriesNode as BitOperationSeriesNode,
+    scout_compute_resolved_api_BodeNode as BodeNode,
     scout_compute_resolved_api_Cartesian3dBounds as Cartesian3dBounds,
     scout_compute_resolved_api_Cartesian3dNode as Cartesian3dNode,
     scout_compute_resolved_api_Cartesian3dNodeVisitor as Cartesian3dNodeVisitor,
@@ -19,6 +20,7 @@ from .._impl import (
     scout_compute_resolved_api_CartesianNodeVisitor as CartesianNodeVisitor,
     scout_compute_resolved_api_ClickHouseSeriesResolutionDetails as ClickHouseSeriesResolutionDetails,
     scout_compute_resolved_api_ConstantDefaultValueResampleInterpolationConfiguration as ConstantDefaultValueResampleInterpolationConfiguration,
+    scout_compute_resolved_api_CpsdNode as CpsdNode,
     scout_compute_resolved_api_CumulativeSumSeriesNode as CumulativeSumSeriesNode,
     scout_compute_resolved_api_CurveFitDetails as CurveFitDetails,
     scout_compute_resolved_api_CurveFitDetailsVisitor as CurveFitDetailsVisitor,
@@ -44,12 +46,15 @@ from .._impl import (
     scout_compute_resolved_api_EnumUnionSeriesNode as EnumUnionSeriesNode,
     scout_compute_resolved_api_EventSearchNode as EventSearchNode,
     scout_compute_resolved_api_ExponentialCurve as ExponentialCurve,
+    scout_compute_resolved_api_ExtractStructFromStructSeriesNode as ExtractStructFromStructSeriesNode,
     scout_compute_resolved_api_ExtremaRangesNode as ExtremaRangesNode,
     scout_compute_resolved_api_FftNode as FftNode,
     scout_compute_resolved_api_FilterByExpressionSeriesNode as FilterByExpressionSeriesNode,
     scout_compute_resolved_api_ForwardFillInterpolation as ForwardFillInterpolation,
     scout_compute_resolved_api_ForwardFillResampleInterpolationConfiguration as ForwardFillResampleInterpolationConfiguration,
     scout_compute_resolved_api_FrequencyDomainNode as FrequencyDomainNode,
+    scout_compute_resolved_api_FrequencyDomainNodeV2 as FrequencyDomainNodeV2,
+    scout_compute_resolved_api_FrequencyDomainNodeV2Visitor as FrequencyDomainNodeV2Visitor,
     scout_compute_resolved_api_FrequencyDomainNodeVisitor as FrequencyDomainNodeVisitor,
     scout_compute_resolved_api_GeoNode as GeoNode,
     scout_compute_resolved_api_GeoNodeSummaryStrategy as GeoNodeSummaryStrategy,
@@ -94,15 +99,16 @@ from .._impl import (
     scout_compute_resolved_api_NumericTimeRangeFilterSeriesNode as NumericTimeRangeFilterSeriesNode,
     scout_compute_resolved_api_NumericTimeShiftSeriesNode as NumericTimeShiftSeriesNode,
     scout_compute_resolved_api_NumericUnionSeriesNode as NumericUnionSeriesNode,
+    scout_compute_resolved_api_NyquistNode as NyquistNode,
     scout_compute_resolved_api_OffsetSeriesNode as OffsetSeriesNode,
     scout_compute_resolved_api_OnChangeRangesNode as OnChangeRangesNode,
     scout_compute_resolved_api_PaddedRangesNode as PaddedRangesNode,
     scout_compute_resolved_api_PercentageThreshold as PercentageThreshold,
-    scout_compute_resolved_api_PeriodogramNode as PeriodogramNode,
     scout_compute_resolved_api_PersistenceWindowConfiguration as PersistenceWindowConfiguration,
     scout_compute_resolved_api_PolynomialCurve as PolynomialCurve,
     scout_compute_resolved_api_PowerCurve as PowerCurve,
     scout_compute_resolved_api_ProductSeriesNode as ProductSeriesNode,
+    scout_compute_resolved_api_PsdNode as PsdNode,
     scout_compute_resolved_api_RangeMap as RangeMap,
     scout_compute_resolved_api_RangesNode as RangesNode,
     scout_compute_resolved_api_RangesNodeVisitor as RangesNodeVisitor,
@@ -180,6 +186,7 @@ __all__ = [
     'BandStopConfiguration',
     'BinaryArithmeticSeriesNode',
     'BitOperationSeriesNode',
+    'BodeNode',
     'Cartesian3dBounds',
     'Cartesian3dNode',
     'Cartesian3dNodeVisitor',
@@ -188,6 +195,7 @@ __all__ = [
     'CartesianNodeVisitor',
     'ClickHouseSeriesResolutionDetails',
     'ConstantDefaultValueResampleInterpolationConfiguration',
+    'CpsdNode',
     'CumulativeSumSeriesNode',
     'CurveFitDetails',
     'CurveFitDetailsVisitor',
@@ -213,6 +221,7 @@ __all__ = [
     'EnumUnionSeriesNode',
     'EventSearchNode',
     'ExponentialCurve',
+    'ExtractStructFromStructSeriesNode',
     'ExtremaRangesNode',
     'FftNode',
     'FilterByExpressionSeriesNode',
@@ -220,6 +229,8 @@ __all__ = [
     'ForwardFillResampleInterpolationConfiguration',
     'FrequencyDomainNode',
     'FrequencyDomainNodeVisitor',
+    'FrequencyDomainNodeV2',
+    'FrequencyDomainNodeV2Visitor',
     'GeoNode',
     'GeoNodeVisitor',
     'GeoNodeSummaryStrategy',
@@ -263,15 +274,16 @@ __all__ = [
     'NumericTimeRangeFilterSeriesNode',
     'NumericTimeShiftSeriesNode',
     'NumericUnionSeriesNode',
+    'NyquistNode',
     'OffsetSeriesNode',
     'OnChangeRangesNode',
     'PaddedRangesNode',
     'PercentageThreshold',
-    'PeriodogramNode',
     'PersistenceWindowConfiguration',
     'PolynomialCurve',
     'PowerCurve',
     'ProductSeriesNode',
+    'PsdNode',
     'RangeMap',
     'RangesNode',
     'RangesNodeVisitor',
